@@ -199,6 +199,23 @@ class BloggingTestCase(BaseTestCase):
 
         self.assertEqual(len(response.json()['items']), 1)
 
+    def test_list_post_ordering_by_title(self):
+        # creating a post to be the last
+        params = {'title': 'zx post test the last',
+                  'authors': [self.users[0].id],
+                  'tags': ['last'],
+                  'content': 'Mussum ipsum cacilds, vidis litro abertis.'}
+
+        response = requests.put(self.base_url, params=params)
+        response.connection.close()
+        # now, listing it
+        params = {'order_by': 'title'}
+        response = requests.get(self.base_url + 'list', params=params)
+        response.connection.close()
+        last_title = response.json()['items'][-1]['title']
+
+        self.assertEqual(last_title, 'zx post test the last')
+
     def test_comment_on_post(self):
         parent_id = self.posts[0].id
         name = 'ze da silva'
