@@ -21,47 +21,53 @@ import os
 import sys
 from tornado import ioloop
 from importlib import import_module
+from pyrocumulus.utils import get_value_from_settings
+from pyrocumulus.conf import settings
 from pyrocumulus.commands.base import BaseCommand
+from pyrocumulus.web.applications import get_main_application
 
 
 class RunTornadoCommand(BaseCommand):
     description = "command to start a tornado server"
     user_options = [
         # some.application.instance
-        {'args': ('application',),
+        {'args': ('--application',),
          'kwargs': {'help': 'application module'}},
         # --daemonize
         {'args': ('--daemonize',),
          'kwargs': {'default': False, 'help': 'run as a daemon',
                     'action': 'store_true'}},
-        # --port=9876
+        # --port 9876
         {'args': ('--port',),
-         'kwargs': {'default': 8888, 'help': 'port to listen'}},
-        # --stdout=some/file.log
+         'kwargs': {'default': None, 'help': 'port to listen',
+                    'nargs': '?'}},
+        # --stdout some/file.log
         {'args': ('--stdout',),
-         'kwargs': {'default': 'logs/stdout.log', 'help': 'stdout log file'}},
-        # --stderr=some/file.log
+         'kwargs': {'default': 'logs/stdout.log', 'help': 'stdout log file',
+                    'nargs': '?'}},
+        # --stderr some/file.log
         {'args': ('--stderr',),
-         'kwargs': {'default': 'logs/stderr.log', 'help': 'stderr log file'}},
-        # --pidfile=some/file.pid
+         'kwargs': {'default': 'logs/stderr.log', 'help': 'stderr log file',
+                    'nargs': '?'}},
+        # --pidfile some/file.pid
         {'args': ('--pidfile',),
-         'kwargs': {'default': None, 'help': 'stderr log file'}},
+         'kwargs': {'default': None, 'help': 'stderr log file',
+                    'nargs': '?'}},
         # --kill
         {'args': ('--kill',),
          'kwargs': {'default': False, 'help': 'kill tornado server',
                     'action': 'store_true'}},
     ]
-        
 
     def run(self):
-        self.application = self._get_application(self.application)
-        self.port = int(self.port)
+        self.application = self.get_application()
+        self.port = self.get_port()
         self.pidfile = self.pidfile or 'tornado-%i.pid' % self.port
 
         if self.kill:
             return self.killtornado()
 
-        print('Starting tornado server')
+        print('Starting tornado server on port %s' % self.port)
         self.application.listen(self.port)
         if self.daemonize:
             self.run_as_a_daemon()
@@ -116,6 +122,12 @@ class RunTornadoCommand(BaseCommand):
         for fd in sys.stdout, sys.stderr:
             fd.flush()
 
+        if not os.path.exists(os.path.dirname(self.stdout)):
+            os.makedirs(os.path.dirname(self.stdout))
+
+        if not os.path.exists(os.path.dirname(self.stderr)):
+            os.makedirs(os.path.dirname(self.stderr))
+
         stdout_fh = open(self.stdout, 'a', 1)
         stderr_fh = open(self.stderr, 'a', 1)
         os.dup2(stdout_fh.fileno(), sys.stdout.fileno())
@@ -146,9 +158,28 @@ class RunTornadoCommand(BaseCommand):
         with open(fname, 'w') as f:
             f.write(content)
 
-    def _get_application(self, app_path):
+    def get_application(self):
+        """
+        application is an instance of tornado.web.Application
+        and will be used in this tornado instance.
+        """
+        if not self.application:
+            return get_main_application()
+
+        app_path = self.application
         module_name = '.'.join(app_path.split('.')[:-1])
         app_name = app_path.split('.')[-1]
         module = import_module(module_name)
         app = getattr(module, app_name)
         return app
+
+    def get_port(self):
+        """
+        Get the port to tornado server listen. If --port command line
+        option, this port will be used. If not command line option
+        get it from TORNADO_PORT settings variable. If not TORNADO_PORT
+        on settings, use 8888
+        """
+        settings_port = get_value_from_settings('TORNADO_PORT', 8888)
+        port = self.port or settings_port
+        return int(port)
