@@ -1,10 +1,8 @@
-#-*- coding: utf-8 -*-
-
 # Copyright 2013 Juca Crispim <jucacrispim@gmail.com>
 
 # This file is part of pyrocumulus.
 
-# pyrocumulus is free software: you can redistribute it and/or modify	
+# pyrocumulus is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
@@ -18,5 +16,16 @@
 # along with pyrocumulus.  If not, see <http://www.gnu.org/licenses/>.
 
 
-class ConverterException(Exception):  # pragma: no cover
-    pass  # pragma: no cover
+class PyrocumulusException(Exception):  # pragma: no cover
+    pass
+
+
+class PyrocumulusConverterException(PyrocumulusException):  # pragma: no cover
+    pass
+
+
+class PyrocumulusCommandNotFound(PyrocumulusException):  # pragma: no cover
+    pass
+
+class TemplateNotFound(PyrocumulusException):  # pagma: no cover
+    pass
